<template>
  <a-modal
    :confirm-loading='confirmLoading1'
    :visible='visible1'
    :width='1100'
    title='函数选择器'
    @cancel='handleCancel'
    @ok='handleOk'
  >
    <a-layout>
      <a-layout-sider style='background: #fff' width='150'>
        <a-tree :expandedKeys.sync='expandedKeys' :tree-data='treeData' default-expand-all
                show-icon @select='onSelect'>
          <template #title='{ key: treeKey, title }'>
            <a-dropdown :trigger="['contextmenu']">
              <span>{{ title }}</span>
              <template #overlay>
                <a-menu @click='({ key: menuKey }) => addProjectModal(treeKey, menuKey)'>
                </a-menu>
              </template>
            </a-dropdown>
          </template>
        </a-tree>
      </a-layout-sider>
      <a-layout style='padding: 0 0 0 1px;overflow: hidden'>
        <a-layout :style="{ background: '#fff', padding: '1px', minHeight: '100%' }">
          <function-information ref='function' @ok='saveParameters' />
        </a-layout>
      </a-layout>
    </a-layout>
  </a-modal>
</template>

<script>
import FunctionInformation from './FunctionInformation'
import pick from 'lodash.pick'
import { getAction } from '@/api/manage'

export default {
  name: 'ScriptFunction',
  components: {
    FunctionInformation
  },
  data() {
    return {
      function: '',
      projectId: '',
      parameterGroupId: '',
      indexStyle: 2,
      expandedKeys: ['0'],
      selectedKeys: [],
      currentSelectedKeys: [],
      visible1: false,
      confirmLoading1: false,
      visible: false,
      disableSubmit: true,
      treeData: [
        {
          title: '转换',
          key: 'Convert'
        },
        {
          title: '数学',
          key: 'Math'
        },
        {
          title: '字符串',
          key: 'String'
        },
        {
          title: '文件',
          key: 'File'
        },
        {
          title: '时间',
          key: 'Time'
        },
        {
          title: '数据库',
          key: 'Database'
        },
        {
          title: '自定义',
          key: 'Custom'
        }
      ],
      load: false,
      url: {
        tree: '/equipment/tree/collect',
        queryByProjectCode: '/projectClassify/queryByProjectCode',
        queryByServe: '/serve/deploy/queryByProjectCode',
        addBatch: '/empty/parameter/addBatch'
      },
      form: this.$form.createForm(this),
      model: {}
    }
  },
  methods: {
    openMqtt() {
      this.visible1 = true
    },
    generateList(data) {
      for (let i = 0; i < data.length; i++) {
        const node = data[i]
        const key = node.key
        this.expandedKeys.push(key)
        if (node.children) {
          this.generateList(node.children)
        }
      }
    },
    // 查询终端列表
    loadData() {
      if (this.serverId) {
        this.parameterGroupId = this.serverId
        // 根据虚设备id查询
        getAction(this.url.tree, { id: this.serverId }).then((res) => {
          if (res.success) {
            this.treeData = res.result
            this.generateList(this.treeData)
          }
          if (res.code === 510) {
            this.$message.warning(res.message)
          }
          this.loading = false
        })
      }
    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onSelectChange(selectedRowKeys) {
      this.selectedRowKeys = selectedRowKeys
    },
    modalFormOk(val) {
      // 调用父组件方法
      this.$emit('tree')
      // 新增/修改 成功时，重载列表
      this.loadData()
      this.selectedRowKeys = [val.id]
    },
    saveParameters(val) {
      // 属性格式 Funtion.StrRegexCount(string input, string str)
      this.function = 'Funtion.' + val[0].state.slice(val[0].dataType.length + 1)
    },
    handleCancel() {
      this.visible1 = false
    },
    add() {
      this.indexStyle = 2
      this.edit({})
      if (this.indexStyle === 2) {
        // 展示设备页面
        getAction(this.url.queryByServe, { projectCode: this.treeData[0].key.split('_')[1] }).then((res) => {
          if (res.success) {
            this.parameterGroupId = res.result.id
            this.indexStyle = 2
          }
        })
      }
    },
    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'parameterCode', 'parameterName', 'parameterDescribe', 'address'))
      })
    },
    handleOk() {
      // 调用父组件方法存储参数
      this.$emit('ok', this.function)
      this.visible1 = false
    },
    onSelect(selectedKeys) {
      // 调用子组件方法
      this.$refs.function.loadData(selectedKeys[0])
    },
    close() {
      this.$emit('close')
      this.visible = false
    }
  }
}
</script>
<style lang='less' scoped>
/deep/ .ant-modal {
  height: 80%;

  .ant-modal-content {
    height: 100%;

    .ant-modal-body {
      height: calc(100% - 52.8px - 54.8px);


      .ant-layout {
        height: 100%;

        .ant-layout-sider {
          height: 100%;
          overflow: auto;
        }
      }

    }
  }
}
</style>

